#ifndef SYMENGINE_CONFIG_CLING_HPP
#define SYMENGINE_CONFIG_CLING_HPP

#pragma cling add_library_path("D:/bld/symengine_1568134056917/_h_env/Library/lib")
#pragma cling load("symengine")

#endif
